(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     26469,       1031]*)
(*NotebookOutlinePosition[     34785,       1310]*)
(*  CellTagsIndexPosition[     33530,       1256]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Cash Flows", "Section",
  CellTags->"0.1"],

Cell["\<\
Cash flows are more general finance objects than bonds. An \
individual cash flow is represented by an ordered pair {time, amount}. The \
time of a flow can be expressed either as a date or as a time interval from a \
given initial date. \
\>", "Text",
  CellTags->"0.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["CashFlows",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["{",
                  "MR"], 
                RowBox[{
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    StyleBox[\(time1, \ amount1\),
                      FontSlant->"Italic"], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[" ",
                    "MR"], 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    StyleBox[\(time2, \ amount2\),
                      FontSlant->"Italic"], 
                    StyleBox["}",
                      "MR"]}], 
                  StyleBox[",",
                    "MR"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["...",
                    "TraditionalForm"]}], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["}",
                  "MR"]}], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            StyleBox[\(an\ object\ representing\ cash\ flows\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell[TextData[{
  StyleBox["CashFlows", "MB"],
  " object. "
}], "Caption"],

Cell[TextData[{
  "First we load the ",
  StyleBox["Finance", "MB"],
  " package. "
}], "MathCaption",
  CellTags->"0.4"],

Cell["<< Finance`", "Input",
  CellLabel->"In[1]:="],

Cell["Here is a cash flows object. ", "MathCaption",
  CellTags->"0.5"],

Cell["\<\
cflows1 = CashFlows[{
                  {{2, 12, 1994}, 100 USDollar},
                  {{3, 15, 1994}, 300 USDollar},
                  {{3, 15, 1995}, 300 USDollar},
                  {{7,  1, 1995}, 150 USDollar},
                  {{10, 30, 1995}, 200 USDollar}}
                  ];\
\>", "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Value",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(cashflows, \ settlement, \ rates\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[" ",
              "TraditionalForm"], 
            
            StyleBox[
              \(return\ the\ present\ value\ of\ the\ cash\ flows\ object\ 
                given\ the\ settlement\ date\ and\ interest\ rates\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["Basic cash flows functions. ", "Caption"],

Cell[TextData[{
  "If we want to use the flat interest rates model, we take ",
  StyleBox["rates", "TI"],
  " to be a single number\[LongDash]the yield to maturity. Otherwise for a \
term structure of interest rates the third argument is an interest rates \
object. In this section we assume that time intervals are expressed in years. \
This also applies to the other functions in the package that have interest \
rates as an argument. "
}], "Text",
  CellTags->"0.7"],

Cell[TextData[{
  "We define an interest rates object ",
  StyleBox["rates1", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.8"],

Cell["\<\
rates1 = DiscountFactors[{{1, 0.91805},
                          {2, 0.84566},
                          {3, 0.77461},
                          {5, 0.65892},
                          {7, 0.55676},
                          {10, 0.41714},
                          {30, 0.06779}},
                          InitialDate -> {1, 1, 1992}];\
\>", "Input",
  CellLabel->"In[3]:="],

Cell["We assume the settlement day is September 15, 1993. ", "MathCaption",
  CellTags->"0.9"],

Cell[CellGroupData[{

Cell["settlement = {9, 15, 1993}", "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({9, 15, 1993}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "Here is the value of ",
  StyleBox["cflows1", "MB"],
  " on August 15, 1993, assuming that the yield to maturity is 12%. "
}], "MathCaption",
  CellTags->"0.10"],

Cell[CellGroupData[{

Cell["val1 = Value[cflows1, settlement, .12]", "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(911.934922825878047`\ USDollar\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "In this case, ",
  StyleBox["Mathematica", "TI"],
  " recognizes that ",
  StyleBox["rates1", "MB"],
  " is an interest rates object and calculates the present value for the \
given structure of interest rates. "
}], "MathCaption",
  CellTags->"0.11"],

Cell[CellGroupData[{

Cell["val2 = Value[cflows1, settlement, rates1]", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(944.266172784836399`\ USDollar\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "We can always create a cash flows finance object that is equivalent to a \
given bond. We redefine ",
  StyleBox["bond10", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.12"],

Cell["bond10 = Bond[{.10, {9, 15, 2003}, 1000 USDollar, 2}];", "Input",
  CellLabel->"In[7]:="],

Cell["We compute the cash flows dates for this bond. ", "MathCaption",
  CellTags->"0.13"],

Cell[CellGroupData[{

Cell["flowDates = CashFlowsDates[bond10, {9, 30, 1993}]", "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({{3, 15, 1994}, {9, 15, 1994}, {3, 15, 1995}, {9, 15, 1995}, {3, 15, 
        1996}, {9, 15, 1996}, {3, 15, 1997}, {9, 15, 1997}, {3, 15, 1998}, {
        9, 15, 1998}, {3, 15, 1999}, {9, 15, 1999}, {3, 15, 2000}, {9, 15, 
        2000}, {3, 15, 2001}, {9, 15, 2001}, {3, 15, 2002}, {9, 15, 2002}, {
        3, 15, 2003}, {9, 15, 2003}}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["Next we create a list of amounts for the cash flows. ", "MathCaption",
  CellTags->"0.14"],

Cell[CellGroupData[{

Cell["\<\
flowAmounts = Append[Table[50 USDollar,
   {Length[flowDates]-1}], 1050 USDollar]\
\>", "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({50\ USDollar, 50\ USDollar, 50\ USDollar, 50\ USDollar, 50\ USDollar, 
      50\ USDollar, 50\ USDollar, 50\ USDollar, 50\ USDollar, 50\ USDollar, 
      50\ USDollar, 50\ USDollar, 50\ USDollar, 50\ USDollar, 50\ USDollar, 
      50\ USDollar, 50\ USDollar, 50\ USDollar, 50\ USDollar, 1050\ USDollar}
      \)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  "Finally we get a cash flows object that is equivalent to ",
  StyleBox["bond10", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.15"],

Cell[CellGroupData[{

Cell["cflows2 = CashFlows[Transpose[{flowDates, flowAmounts}]]", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(CashFlows[{{{3, 15, 1994}, 50\ USDollar}, {{9, 15, 1994}, 
          50\ USDollar}, {{3, 15, 1995}, 50\ USDollar}, {{9, 15, 1995}, 
          50\ USDollar}, {{3, 15, 1996}, 50\ USDollar}, {{9, 15, 1996}, 
          50\ USDollar}, {{3, 15, 1997}, 50\ USDollar}, {{9, 15, 1997}, 
          50\ USDollar}, {{3, 15, 1998}, 50\ USDollar}, {{9, 15, 1998}, 
          50\ USDollar}, {{3, 15, 1999}, 50\ USDollar}, {{9, 15, 1999}, 
          50\ USDollar}, {{3, 15, 2000}, 50\ USDollar}, {{9, 15, 2000}, 
          50\ USDollar}, {{3, 15, 2001}, 50\ USDollar}, {{9, 15, 2001}, 
          50\ USDollar}, {{3, 15, 2002}, 50\ USDollar}, {{9, 15, 2002}, 
          50\ USDollar}, {{3, 15, 2003}, 50\ USDollar}, {{9, 15, 2003}, 
          1050\ USDollar}}]\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "The value of ",
  StyleBox["cflows2", "MB"],
  " should be identical to that of ",
  StyleBox["bond10", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.16"],

Cell[CellGroupData[{

Cell["val3 = Value[cflows2, settlement, .12]", "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(903.584870881421053`\ USDollar\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["There is a discrepancy. ", "MathCaption",
  CellTags->"0.17"],

Cell[CellGroupData[{

Cell["val4 = Value[bond10, settlement, .12]", "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(885.300787814346179`\ USDollar\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "The first reason is the difference between the effective and nominal \
rates. In the value of cash flows, we are using annual rates although ",
  StyleBox["bond10", "MB"],
  " pays semiannually. Here is the correct annual rate. "
}], "MathCaption",
  CellTags->"0.18"],

Cell[CellGroupData[{

Cell["effrate = NominalRate[12/100, 2, 1] // N", "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(0.123599999999999998`\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["We get slightly better agreement. ", "MathCaption",
  CellTags->"0.19"],

Cell[CellGroupData[{

Cell["val5 = Value[cflows2, settlement, effrate]", "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(885.421356473129073`\ USDollar\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
The second reason is that in the case of cash flows calculation, \
the time intervals are not necessarily equal since we use the actual calendar \
day count. \
\>", "MathCaption",
  CellTags->"0.20"],

Cell[CellGroupData[{

Cell["YearsBetween[{9, 15, 1994}, {3, 15, 1994}]", "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(184\/365\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "The time periods are not exactly half\[Hyphen]years, as we assume with \
bonds. Defining the time intervals to be ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)], "InlineFormula"],
  ", 1, ",
  Cell[BoxData[
      \(TraditionalForm\`3\/2\)], "InlineFormula"],
  ", ... will make the results for bonds and their equivalent cash flows \
agree. "
}], "MathCaption",
  CellTags->"0.21"],

Cell[CellGroupData[{

Cell["YearsBetween[{3, 15, 1995}, {9, 15, 1994}]", "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(181\/365\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
We define a new object that takes this into account. Here the dates \
in the cash flows object have been replaced by time intervals starting at a \
given initial date. \
\>", "MathCaption",
  CellTags->"0.22"],

Cell[CellGroupData[{

Cell["\<\
cflows3 = CashFlows[Append[Table[{i, 50 USDollar},
   {i, 1/2, 9 + 1/2, 1/2}], {10, 1050 USDollar}],
   InitialDate -> {9, 15, 1993}]\
\>", "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(CashFlows[{{1\/2, 50\ USDollar}, {1, 50\ USDollar}, {3\/2, 
          50\ USDollar}, {2, 50\ USDollar}, {5\/2, 50\ USDollar}, {3, 
          50\ USDollar}, {7\/2, 50\ USDollar}, {4, 50\ USDollar}, {9\/2, 
          50\ USDollar}, {5, 50\ USDollar}, {11\/2, 50\ USDollar}, {6, 
          50\ USDollar}, {13\/2, 50\ USDollar}, {7, 50\ USDollar}, {15\/2, 
          50\ USDollar}, {8, 50\ USDollar}, {17\/2, 50\ USDollar}, {9, 
          50\ USDollar}, {19\/2, 50\ USDollar}, {10, 1050\ USDollar}}, 
      InitialDate \[Rule] {9, 15, 1993}]\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "Here is the value of ",
  StyleBox["cashflow3", "MB"],
  ". It is equal to ",
  StyleBox["val4", "MB"],
  ", as it should be. "
}], "MathCaption",
  CellTags->"0.23"],

Cell[CellGroupData[{

Cell["val5 = Value[cflows3, settlement, effrate]", "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(885.300787814347778`\ USDollar\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[TextData[{
  "This is the value of the cash flows object, equivalent to ",
  StyleBox["bond10", "MB"],
  " using the interest rates object ",
  StyleBox["rates1", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.24"],

Cell[CellGroupData[{

Cell["val6 = Value[cflows3, settlement, rates1]", "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(1068.94625559631495`\ USDollar\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["YieldToMaturity",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(cashflows, \ price, \ settlement\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], " "}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[" ",
              "TraditionalForm"], 
            
            StyleBox[
              \(return\ the\ yield\ to\ maturity\ of\ the\ cash\ flows\ object
                \ given\ its\ price\ and\ settlement\ date\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["Additional cash flows function. ", "Caption"],

Cell[TextData[{
  "Now we compute the yield to maturity for ",
  StyleBox["cflows1", "MB"],
  ", ",
  StyleBox["cflows2", "MB"],
  ", and ",
  StyleBox["cflows3", "MB"],
  " using the prices ",
  StyleBox["val1", "MB"],
  ", ",
  StyleBox["val3", "MB"],
  ", and ",
  StyleBox["val5", "MB"],
  ". We get the expected results. "
}], "MathCaption",
  CellTags->"0.26"],

Cell[CellGroupData[{

Cell["YieldToMaturity[cflows1, val1, settlement]", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(0.119999999998237093`\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["YieldToMaturity[cflows2, val3, settlement]", "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(0.119999983033938683`\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({YieldToMaturity[cflows3, \ val5, \ settlement], \ \ effrate\ }\)], 
  "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({0.123599994261580437`, 0.123599999999999998`}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Duration",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(cashflows, \ settlement, \ rates\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ Macaulay\ duration\ of\ the\ cash\ flows\ object
                \ given\ the\ settlement\ date\ and\ interest\ rates\),
              "TraditionalForm"]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Convexity",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(cashflows, \ settlement, \ rates\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], " "}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ convexity\ of\ the\ cash\ flows\ object\ given\ 
                the\ settlement\ date\ and\ interest\ rates\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["Cash flows sensitivity measure functions. ", "Caption"],

Cell[TextData[{
  "Here we compute the duration for ",
  StyleBox["cflows1", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.28"],

Cell[CellGroupData[{

Cell["Duration[cflows1, settlement, .12]", "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(1.21923597939886962`\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "Here we compute the duration for ",
  StyleBox["cflows2", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.29"],

Cell[CellGroupData[{

Cell["Duration[cflows2, settlement, .12]", "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(6.34762647545343217`\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[TextData[{
  "We expect this to be equal to the duration of ",
  StyleBox["bond10", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.30"],

Cell[CellGroupData[{

Cell["Duration[cflows3, settlement, effrate]", "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(6.30921884767875429`\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "They are indeed identical. Since ",
  StyleBox["bond10", "MB"],
  " pays semiannually, the duration is calculated in half\[Hyphen]years by \
default, and so we divide by 2. "
}], "MathCaption",
  CellTags->"0.31"],

Cell[CellGroupData[{

Cell["Duration[bond10, settlement, .12] / 2", "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(6.30921884767875074`\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "Here we compute the convexity for ",
  StyleBox["cflows1", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.32"],

Cell[CellGroupData[{

Cell["Convexity[cflows1, settlement, .12]", "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(3.14304836452404723`\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[TextData[{
  "Here we compute the convexity for ",
  StyleBox["cflows2", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.33"],

Cell[CellGroupData[{

Cell["Convexity[cflows2, settlement, .12]", "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(59.0483167043580969`\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  "We expect this to be equal to the convexity of ",
  StyleBox["bond10", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.34"],

Cell[CellGroupData[{

Cell["Convexity[cflows3, settlement, effrate]", "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(58.5586540165487257`\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
We divide by 4, since by default the convexity of a bond is \
computed in periods squared. \
\>", "MathCaption",
  CellTags->"0.35"],

Cell[CellGroupData[{

Cell["Convexity[bond10, settlement, .12] / 2^2", "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(58.5586540165486812`\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["Of course, we can use different currencies. ", "MathCaption",
  CellTags->"0.36"],

Cell["\<\
cflows4 = CashFlows[
                 {{{ 2, 12, 1993}, 1000 USDollar},
                  {{ 3, 15, 1993}, 20000 GermanMark},
                  {{ 3, 15, 1994}, -5000 BritishPound},
                  {{ 7,  1, 1994}, 68000 JapaneseYen},
                  {{10, 30, 1994}, 17000 FrenchFranc}}];\
\>", "Input",
  CellLabel->"In[31]:="],

Cell["Simple Representation of Cash Flows", "Subsection",
  CellTags->{"S0.1", "1.1"}],

Cell[TextData[{
  "Under certain conditions that arise in practice, we can make the functions \
",
  StyleBox["Value", "MB"],
  ", ",
  StyleBox["Duration", "MB"],
  ", and ",
  StyleBox["Convexity", "MB"],
  " simpler and their evaluation faster. The settlement date and the initial \
dates for both the cash flows and interest rates must be the same and the \
cash flows object must be represented in the form {{",
  StyleBox["interval", "TI"],
  ", ",
  StyleBox["amount", "TI"],
  "}, ... }. "
}], "Text",
  CellTags->{"S0.1", "1.2"}],

Cell[TextData[{
  "We define the cash flows object ",
  StyleBox["cf1", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.1", "1.3"}],

Cell["\<\
cf1 = CashFlows[{{42/365, 100 USDollar},
                 {73/365, 300 USDollar},
                 {438/365, 300 USDollar},
                 {546/365, 150 USDollar},
                 {667/365, 200 USDollar}}];\
\>", "Input",
  CellLabel->"In[32]:=",
  CellTags->"S0.1"],

Cell[TextData[{
  "This cash flows object is equivalent to ",
  StyleBox["bond30", "MB"],
  ", which was defined in the previous section as a 30\[Hyphen]year, 10% U.S. \
Treasury bond paying semiannually. "
}], "MathCaption",
  CellTags->{"S0.1", "1.4"}],

Cell["\<\
cf2 = CashFlows[Append[Table[{i, 5 USDollar},
   {i, 1/2, 29+1/2, 1/2}], {30, 105 USDollar}]];\
\>", "Input",
  CellLabel->"In[33]:=",
  CellTags->"S0.1"],

Cell["We will need the annualized interest rate of this bond. ", "MathCaption",
  CellTags->{"S0.1", "1.5"}],

Cell[CellGroupData[{

Cell["ir = NominalRate[.05, 2, 1]", "Input",
  CellLabel->"In[34]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(0.05062499999999992`\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[TextData[{
  "Here is the value of ",
  StyleBox["cf1", "MB"],
  " for a 12% yield to maturity. "
}], "MathCaption",
  CellTags->{"S0.1", "1.6"}],

Cell[CellGroupData[{

Cell["Value[cf1, .12]", "Input",
  CellLabel->"In[35]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(943.033212680138888`\ USDollar\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
  "The value of ",
  StyleBox["cf2", "MB"],
  " equals the value of ",
  StyleBox["bond30", "MB"],
  " on the issue day. "
}], "MathCaption",
  CellTags->{"S0.1", "1.7"}],

Cell[CellGroupData[{

Cell["Value[cf2, ir]", "Input",
  CellLabel->"In[36]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(177.271641212644048`\ USDollar\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[TextData[{
  "Here is the duration of ",
  StyleBox["cf1", "MB"],
  " assuming a 12% yield to maturity. "
}], "MathCaption",
  CellTags->{"S0.1", "1.8"}],

Cell[CellGroupData[{

Cell["Duration[cf1, .12]", "Input",
  CellLabel->"In[37]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(0.923345568439961894`\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  "Here is the duration of ",
  StyleBox["cf2", "MB"],
  ". This is the same as the duration of ",
  StyleBox["bond30", "MB"],
  " in years on the issue day. "
}], "MathCaption",
  CellTags->{"S0.1", "1.9"}],

Cell[CellGroupData[{

Cell["Duration[cf2, ir]", "Input",
  CellLabel->"In[38]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(14.0252919705037477`\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[TextData[{
  "Here is the convexity of ",
  StyleBox["cf1", "MB"],
  " assuming a 12% yield to maturity. "
}], "MathCaption",
  CellTags->{"S0.1", "1.10"}],

Cell[CellGroupData[{

Cell["Convexity[cf1, .12]", "Input",
  CellLabel->"In[39]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(2.21318861886213369`\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[TextData[{
  "Here is the convexity of ",
  StyleBox["cf2", "MB"],
  ". This is the same as the convexity of ",
  StyleBox["bond30", "MB"],
  " on the issue day. "
}], "MathCaption",
  CellTags->{"S0.1", "1.11"}],

Cell[CellGroupData[{

Cell["Convexity[cf2, ir]", "Input",
  CellLabel->"In[40]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(307.034790572549365`\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell["\<\
So far we have used the flat interest rates model. Now we give \
examples of computations using an interest rates object. \
\>", "Text",
  CellTags->{"S0.1", "1.12"}],

Cell[TextData[{
  "We define the interest rates object ",
  StyleBox["rates0", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.1", "1.13"}],

Cell["\<\
rates0 = DiscountFactors[
                {{1, 0.91805},
                 {2, 0.84566},
                 {3, 0.77461},
                 {5, 0.65892},
                 {7, 0.55676},
                 {10, 0.41714},
                 {30, 0.06779}}];\
\>", "Input",
  CellLabel->"In[41]:=",
  CellTags->"S0.1"],

Cell[TextData[{
  "Here is the value of the cash flows ",
  StyleBox["cf1", "MB"],
  ". "
}], "MathCaption",
  CellTags->{"S0.1", "1.15"}],

Cell[CellGroupData[{

Cell["Value[cf1, rates0]", "Input",
  CellLabel->"In[42]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(968.620305073598686`\ USDollar\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[{
  "This is the duration of ",
  StyleBox["cf1", "MB"],
  " in years. "
}], "MathCaption",
  CellTags->{"S0.1", "1.16"}],

Cell[CellGroupData[{

Cell["Duration[cf1, rates0]", "Input",
  CellLabel->"In[43]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(0.936123350859856095`\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell["This is its convexity in years squared. ", "MathCaption",
  CellTags->{"S0.1", "1.17"}],

Cell[CellGroupData[{

Cell["Convexity[cf1, rates0]", "Input",
  CellLabel->"In[44]:=",
  CellTags->"S0.1"],

Cell[BoxData[
    \(2.24928141257988079`\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{500, 350},
WindowMargins->{{-1, Automatic}, {Automatic, 0}},
StyleDefinitions -> "ApplicationManual.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "0.1"->{
    Cell[1717, 49, 48, 1, 72, "Section",
      CellTags->"0.1"]},
  "0.2"->{
    Cell[1768, 52, 281, 6, 71, "Text",
      CellTags->"0.2"]},
  "0.4"->{
    Cell[3702, 118, 121, 5, 32, "MathCaption",
      CellTags->"0.4"]},
  "0.5"->{
    Cell[3881, 128, 71, 1, 31, "MathCaption",
      CellTags->"0.5"]},
  "0.7"->{
    Cell[5119, 172, 469, 9, 86, "Text",
      CellTags->"0.7"]},
  "0.8"->{
    Cell[5591, 183, 129, 5, 30, "MathCaption",
      CellTags->"0.8"]},
  "0.9"->{
    Cell[6113, 202, 94, 1, 30, "MathCaption",
      CellTags->"0.9"]},
  "0.10"->{
    Cell[6388, 215, 180, 5, 46, "MathCaption",
      CellTags->"0.10"]},
  "0.11"->{
    Cell[6778, 232, 270, 8, 46, "MathCaption",
      CellTags->"0.11"]},
  "0.12"->{
    Cell[7261, 252, 194, 6, 46, "MathCaption",
      CellTags->"0.12"]},
  "0.13"->{
    Cell[7556, 263, 90, 1, 30, "MathCaption",
      CellTags->"0.13"]},
  "0.14"->{
    Cell[8173, 280, 96, 1, 30, "MathCaption",
      CellTags->"0.14"]},
  "0.15"->{
    Cell[8810, 300, 152, 5, 30, "MathCaption",
      CellTags->"0.15"]},
  "0.16"->{
    Cell[9905, 327, 175, 7, 30, "MathCaption",
      CellTags->"0.16"]},
  "0.17"->{
    Cell[10292, 346, 67, 1, 30, "MathCaption",
      CellTags->"0.17"]},
  "0.18"->{
    Cell[10570, 359, 287, 6, 62, "MathCaption",
      CellTags->"0.18"]},
  "0.19"->{
    Cell[11062, 377, 77, 1, 30, "MathCaption",
      CellTags->"0.19"]},
  "0.20"->{
    Cell[11355, 390, 209, 5, 46, "MathCaption",
      CellTags->"0.20"]},
  "0.21"->{
    Cell[11758, 407, 405, 11, 68, "MathCaption",
      CellTags->"0.21"]},
  "0.22"->{
    Cell[12357, 430, 219, 5, 46, "MathCaption",
      CellTags->"0.22"]},
  "0.23"->{
    Cell[13398, 458, 185, 7, 30, "MathCaption",
      CellTags->"0.23"]},
  "0.24"->{
    Cell[13799, 477, 220, 7, 46, "MathCaption",
      CellTags->"0.24"]},
  "0.26"->{
    Cell[15011, 524, 366, 15, 46, "MathCaption",
      CellTags->"0.26"]},
  "0.28"->{
    Cell[17510, 625, 129, 5, 30, "MathCaption",
      CellTags->"0.28"]},
  "0.29"->{
    Cell[17837, 642, 129, 5, 30, "MathCaption",
      CellTags->"0.29"]},
  "0.30"->{
    Cell[18164, 659, 141, 5, 30, "MathCaption",
      CellTags->"0.30"]},
  "0.31"->{
    Cell[18507, 676, 232, 6, 46, "MathCaption",
      CellTags->"0.31"]},
  "0.32"->{
    Cell[18940, 694, 130, 5, 30, "MathCaption",
      CellTags->"0.32"]},
  "0.33"->{
    Cell[19269, 711, 130, 5, 30, "MathCaption",
      CellTags->"0.33"]},
  "0.34"->{
    Cell[19598, 728, 142, 5, 30, "MathCaption",
      CellTags->"0.34"]},
  "0.35"->{
    Cell[19943, 745, 142, 4, 30, "MathCaption",
      CellTags->"0.35"]},
  "0.36"->{
    Cell[20289, 761, 87, 1, 30, "MathCaption",
      CellTags->"0.36"]},
  "S0.1"->{
    Cell[20725, 774, 86, 1, 55, "Subsection",
      CellTags->{"S0.1", "1.1"}],
    Cell[20814, 777, 538, 16, 86, "Text",
      CellTags->{"S0.1", "1.2"}],
    Cell[21355, 795, 133, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.3"}],
    Cell[21491, 802, 279, 8, 87, "Input",
      CellTags->"S0.1"],
    Cell[21773, 812, 254, 6, 46, "MathCaption",
      CellTags->{"S0.1", "1.4"}],
    Cell[22030, 820, 164, 5, 42, "Input",
      CellTags->"S0.1"],
    Cell[22197, 827, 108, 1, 30, "MathCaption",
      CellTags->{"S0.1", "1.5"}],
    Cell[22330, 832, 89, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[22516, 841, 150, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.6"}],
    Cell[22691, 850, 77, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[22875, 859, 186, 7, 30, "MathCaption",
      CellTags->{"S0.1", "1.7"}],
    Cell[23086, 870, 76, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[23269, 879, 158, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.8"}],
    Cell[23452, 888, 80, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[23630, 897, 223, 7, 46, "MathCaption",
      CellTags->{"S0.1", "1.9"}],
    Cell[23878, 908, 79, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[24054, 917, 160, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.10"}],
    Cell[24239, 926, 81, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[24417, 935, 217, 7, 46, "MathCaption",
      CellTags->{"S0.1", "1.11"}],
    Cell[24659, 946, 80, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[24836, 955, 176, 4, 50, "Text",
      CellTags->{"S0.1", "1.12"}],
    Cell[25015, 961, 141, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.13"}],
    Cell[25159, 968, 316, 11, 132, "Input",
      CellTags->"S0.1"],
    Cell[25478, 981, 138, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.15"}],
    Cell[25641, 990, 80, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[25828, 999, 135, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.16"}],
    Cell[25988, 1008, 83, 2, 27, "Input",
      CellTags->"S0.1"],
    Cell[26169, 1017, 93, 1, 30, "MathCaption",
      CellTags->{"S0.1", "1.17"}],
    Cell[26287, 1022, 84, 2, 27, "Input",
      CellTags->"S0.1"]},
  "1.1"->{
    Cell[20725, 774, 86, 1, 55, "Subsection",
      CellTags->{"S0.1", "1.1"}]},
  "1.2"->{
    Cell[20814, 777, 538, 16, 86, "Text",
      CellTags->{"S0.1", "1.2"}]},
  "1.3"->{
    Cell[21355, 795, 133, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.3"}]},
  "1.4"->{
    Cell[21773, 812, 254, 6, 46, "MathCaption",
      CellTags->{"S0.1", "1.4"}]},
  "1.5"->{
    Cell[22197, 827, 108, 1, 30, "MathCaption",
      CellTags->{"S0.1", "1.5"}]},
  "1.6"->{
    Cell[22516, 841, 150, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.6"}]},
  "1.7"->{
    Cell[22875, 859, 186, 7, 30, "MathCaption",
      CellTags->{"S0.1", "1.7"}]},
  "1.8"->{
    Cell[23269, 879, 158, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.8"}]},
  "1.9"->{
    Cell[23630, 897, 223, 7, 46, "MathCaption",
      CellTags->{"S0.1", "1.9"}]},
  "1.10"->{
    Cell[24054, 917, 160, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.10"}]},
  "1.11"->{
    Cell[24417, 935, 217, 7, 46, "MathCaption",
      CellTags->{"S0.1", "1.11"}]},
  "1.12"->{
    Cell[24836, 955, 176, 4, 50, "Text",
      CellTags->{"S0.1", "1.12"}]},
  "1.13"->{
    Cell[25015, 961, 141, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.13"}]},
  "1.15"->{
    Cell[25478, 981, 138, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.15"}]},
  "1.16"->{
    Cell[25828, 999, 135, 5, 30, "MathCaption",
      CellTags->{"S0.1", "1.16"}]},
  "1.17"->{
    Cell[26169, 1017, 93, 1, 30, "MathCaption",
      CellTags->{"S0.1", "1.17"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"0.1", 27133, 1049},
  {"0.2", 27210, 1052},
  {"0.4", 27285, 1055},
  {"0.5", 27368, 1058},
  {"0.7", 27450, 1061},
  {"0.8", 27526, 1064},
  {"0.9", 27609, 1067},
  {"0.10", 27692, 1070},
  {"0.11", 27777, 1073},
  {"0.12", 27862, 1076},
  {"0.13", 27947, 1079},
  {"0.14", 28031, 1082},
  {"0.15", 28115, 1085},
  {"0.16", 28200, 1088},
  {"0.17", 28285, 1091},
  {"0.18", 28370, 1094},
  {"0.19", 28456, 1097},
  {"0.20", 28541, 1100},
  {"0.21", 28627, 1103},
  {"0.22", 28714, 1106},
  {"0.23", 28800, 1109},
  {"0.24", 28886, 1112},
  {"0.26", 28972, 1115},
  {"0.28", 29059, 1118},
  {"0.29", 29145, 1121},
  {"0.30", 29231, 1124},
  {"0.31", 29317, 1127},
  {"0.32", 29403, 1130},
  {"0.33", 29489, 1133},
  {"0.34", 29575, 1136},
  {"0.35", 29661, 1139},
  {"0.36", 29747, 1142},
  {"S0.1", 29832, 1145},
  {"1.1", 32013, 1204},
  {"1.2", 32105, 1207},
  {"1.3", 32193, 1210},
  {"1.4", 32287, 1213},
  {"1.5", 32381, 1216},
  {"1.6", 32475, 1219},
  {"1.7", 32569, 1222},
  {"1.8", 32663, 1225},
  {"1.9", 32757, 1228},
  {"1.10", 32852, 1231},
  {"1.11", 32948, 1234},
  {"1.12", 33044, 1237},
  {"1.13", 33133, 1240},
  {"1.15", 33229, 1243},
  {"1.16", 33325, 1246},
  {"1.17", 33421, 1249}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 48, 1, 72, "Section",
  CellTags->"0.1"],
Cell[1768, 52, 281, 6, 71, "Text",
  CellTags->"0.2"],
Cell[2052, 60, 1389, 44, 41, InheritFromParent],
Cell[3444, 106, 177, 5, 26, InheritFromParent],
Cell[3624, 113, 75, 3, 16, "Caption"],
Cell[3702, 118, 121, 5, 32, "MathCaption",
  CellTags->"0.4"],
Cell[3826, 125, 52, 1, 30, "Input"],
Cell[3881, 128, 71, 1, 31, "MathCaption",
  CellTags->"0.5"],
Cell[3955, 131, 337, 9, 138, "Input"],
Cell[4295, 142, 418, 14, 41, InheritFromParent],
Cell[4716, 158, 350, 10, 40, InheritFromParent],
Cell[5069, 170, 47, 0, 15, "Caption"],
Cell[5119, 172, 469, 9, 86, "Text",
  CellTags->"0.7"],
Cell[5591, 183, 129, 5, 30, "MathCaption",
  CellTags->"0.8"],
Cell[5723, 190, 387, 10, 132, "Input"],
Cell[6113, 202, 94, 1, 30, "MathCaption",
  CellTags->"0.9"],

Cell[CellGroupData[{
Cell[6232, 207, 67, 1, 27, "Input"],
Cell[6302, 210, 71, 2, 27, "Output"]
}, Open  ]],
Cell[6388, 215, 180, 5, 46, "MathCaption",
  CellTags->"0.10"],

Cell[CellGroupData[{
Cell[6593, 224, 79, 1, 27, "Input"],
Cell[6675, 227, 88, 2, 27, "Output"]
}, Open  ]],
Cell[6778, 232, 270, 8, 46, "MathCaption",
  CellTags->"0.11"],

Cell[CellGroupData[{
Cell[7073, 244, 82, 1, 27, "Input"],
Cell[7158, 247, 88, 2, 27, "Output"]
}, Open  ]],
Cell[7261, 252, 194, 6, 46, "MathCaption",
  CellTags->"0.12"],
Cell[7458, 260, 95, 1, 27, "Input"],
Cell[7556, 263, 90, 1, 30, "MathCaption",
  CellTags->"0.13"],

Cell[CellGroupData[{
Cell[7671, 268, 90, 1, 27, "Input"],
Cell[7764, 271, 394, 6, 91, "Output"]
}, Open  ]],
Cell[8173, 280, 96, 1, 30, "MathCaption",
  CellTags->"0.14"],

Cell[CellGroupData[{
Cell[8294, 285, 130, 4, 42, "Input"],
Cell[8427, 291, 368, 6, 75, "Output"]
}, Open  ]],
Cell[8810, 300, 152, 5, 30, "MathCaption",
  CellTags->"0.15"],

Cell[CellGroupData[{
Cell[8987, 309, 98, 1, 27, "Input"],
Cell[9088, 312, 802, 12, 187, "Output"]
}, Open  ]],
Cell[9905, 327, 175, 7, 30, "MathCaption",
  CellTags->"0.16"],

Cell[CellGroupData[{
Cell[10105, 338, 80, 1, 27, "Input"],
Cell[10188, 341, 89, 2, 27, "Output"]
}, Open  ]],
Cell[10292, 346, 67, 1, 30, "MathCaption",
  CellTags->"0.17"],

Cell[CellGroupData[{
Cell[10384, 351, 79, 1, 27, "Input"],
Cell[10466, 354, 89, 2, 27, "Output"]
}, Open  ]],
Cell[10570, 359, 287, 6, 62, "MathCaption",
  CellTags->"0.18"],

Cell[CellGroupData[{
Cell[10882, 369, 82, 1, 27, "Input"],
Cell[10967, 372, 80, 2, 27, "Output"]
}, Open  ]],
Cell[11062, 377, 77, 1, 30, "MathCaption",
  CellTags->"0.19"],

Cell[CellGroupData[{
Cell[11164, 382, 84, 1, 27, "Input"],
Cell[11251, 385, 89, 2, 27, "Output"]
}, Open  ]],
Cell[11355, 390, 209, 5, 46, "MathCaption",
  CellTags->"0.20"],

Cell[CellGroupData[{
Cell[11589, 399, 84, 1, 27, "Input"],
Cell[11676, 402, 67, 2, 43, "Output"]
}, Open  ]],
Cell[11758, 407, 405, 11, 68, "MathCaption",
  CellTags->"0.21"],

Cell[CellGroupData[{
Cell[12188, 422, 84, 1, 27, "Input"],
Cell[12275, 425, 67, 2, 43, "Output"]
}, Open  ]],
Cell[12357, 430, 219, 5, 46, "MathCaption",
  CellTags->"0.22"],

Cell[CellGroupData[{
Cell[12601, 439, 183, 5, 57, "Input"],
Cell[12787, 446, 596, 9, 286, "Output"]
}, Open  ]],
Cell[13398, 458, 185, 7, 30, "MathCaption",
  CellTags->"0.23"],

Cell[CellGroupData[{
Cell[13608, 469, 84, 1, 27, "Input"],
Cell[13695, 472, 89, 2, 27, "Output"]
}, Open  ]],
Cell[13799, 477, 220, 7, 46, "MathCaption",
  CellTags->"0.24"],

Cell[CellGroupData[{
Cell[14044, 488, 83, 1, 27, "Input"],
Cell[14130, 491, 89, 2, 27, "Output"]
}, Open  ]],
Cell[14234, 496, 372, 12, 40, InheritFromParent],
Cell[14609, 510, 345, 10, 40, InheritFromParent],
Cell[14957, 522, 51, 0, 15, "Caption"],
Cell[15011, 524, 366, 15, 46, "MathCaption",
  CellTags->"0.26"],

Cell[CellGroupData[{
Cell[15402, 543, 84, 1, 27, "Input"],
Cell[15489, 546, 80, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15606, 553, 84, 1, 27, "Input"],
Cell[15693, 556, 80, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15810, 563, 124, 3, 27, "Input"],
Cell[15937, 568, 105, 2, 27, "Output"]
}, Open  ]],
Cell[16057, 573, 421, 14, 40, InheritFromParent],
Cell[16481, 589, 298, 8, 40, InheritFromParent],
Cell[16782, 599, 369, 12, 32, InheritFromParent],
Cell[17154, 613, 289, 8, 40, InheritFromParent],
Cell[17446, 623, 61, 0, 15, "Caption"],
Cell[17510, 625, 129, 5, 30, "MathCaption",
  CellTags->"0.28"],

Cell[CellGroupData[{
Cell[17664, 634, 76, 1, 27, "Input"],
Cell[17743, 637, 79, 2, 27, "Output"]
}, Open  ]],
Cell[17837, 642, 129, 5, 30, "MathCaption",
  CellTags->"0.29"],

Cell[CellGroupData[{
Cell[17991, 651, 76, 1, 27, "Input"],
Cell[18070, 654, 79, 2, 27, "Output"]
}, Open  ]],
Cell[18164, 659, 141, 5, 30, "MathCaption",
  CellTags->"0.30"],

Cell[CellGroupData[{
Cell[18330, 668, 80, 1, 27, "Input"],
Cell[18413, 671, 79, 2, 27, "Output"]
}, Open  ]],
Cell[18507, 676, 232, 6, 46, "MathCaption",
  CellTags->"0.31"],

Cell[CellGroupData[{
Cell[18764, 686, 79, 1, 27, "Input"],
Cell[18846, 689, 79, 2, 27, "Output"]
}, Open  ]],
Cell[18940, 694, 130, 5, 30, "MathCaption",
  CellTags->"0.32"],

Cell[CellGroupData[{
Cell[19095, 703, 77, 1, 27, "Input"],
Cell[19175, 706, 79, 2, 27, "Output"]
}, Open  ]],
Cell[19269, 711, 130, 5, 30, "MathCaption",
  CellTags->"0.33"],

Cell[CellGroupData[{
Cell[19424, 720, 77, 1, 27, "Input"],
Cell[19504, 723, 79, 2, 27, "Output"]
}, Open  ]],
Cell[19598, 728, 142, 5, 30, "MathCaption",
  CellTags->"0.34"],

Cell[CellGroupData[{
Cell[19765, 737, 81, 1, 27, "Input"],
Cell[19849, 740, 79, 2, 27, "Output"]
}, Open  ]],
Cell[19943, 745, 142, 4, 30, "MathCaption",
  CellTags->"0.35"],

Cell[CellGroupData[{
Cell[20110, 753, 82, 1, 27, "Input"],
Cell[20195, 756, 79, 2, 27, "Output"]
}, Open  ]],
Cell[20289, 761, 87, 1, 30, "MathCaption",
  CellTags->"0.36"],
Cell[20379, 764, 343, 8, 102, "Input"],
Cell[20725, 774, 86, 1, 55, "Subsection",
  CellTags->{"S0.1", "1.1"}],
Cell[20814, 777, 538, 16, 86, "Text",
  CellTags->{"S0.1", "1.2"}],
Cell[21355, 795, 133, 5, 30, "MathCaption",
  CellTags->{"S0.1", "1.3"}],
Cell[21491, 802, 279, 8, 87, "Input",
  CellTags->"S0.1"],
Cell[21773, 812, 254, 6, 46, "MathCaption",
  CellTags->{"S0.1", "1.4"}],
Cell[22030, 820, 164, 5, 42, "Input",
  CellTags->"S0.1"],
Cell[22197, 827, 108, 1, 30, "MathCaption",
  CellTags->{"S0.1", "1.5"}],

Cell[CellGroupData[{
Cell[22330, 832, 89, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[22422, 836, 79, 2, 27, "Output"]
}, Open  ]],
Cell[22516, 841, 150, 5, 30, "MathCaption",
  CellTags->{"S0.1", "1.6"}],

Cell[CellGroupData[{
Cell[22691, 850, 77, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[22771, 854, 89, 2, 27, "Output"]
}, Open  ]],
Cell[22875, 859, 186, 7, 30, "MathCaption",
  CellTags->{"S0.1", "1.7"}],

Cell[CellGroupData[{
Cell[23086, 870, 76, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[23165, 874, 89, 2, 27, "Output"]
}, Open  ]],
Cell[23269, 879, 158, 5, 30, "MathCaption",
  CellTags->{"S0.1", "1.8"}],

Cell[CellGroupData[{
Cell[23452, 888, 80, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[23535, 892, 80, 2, 27, "Output"]
}, Open  ]],
Cell[23630, 897, 223, 7, 46, "MathCaption",
  CellTags->{"S0.1", "1.9"}],

Cell[CellGroupData[{
Cell[23878, 908, 79, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[23960, 912, 79, 2, 27, "Output"]
}, Open  ]],
Cell[24054, 917, 160, 5, 30, "MathCaption",
  CellTags->{"S0.1", "1.10"}],

Cell[CellGroupData[{
Cell[24239, 926, 81, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[24323, 930, 79, 2, 27, "Output"]
}, Open  ]],
Cell[24417, 935, 217, 7, 46, "MathCaption",
  CellTags->{"S0.1", "1.11"}],

Cell[CellGroupData[{
Cell[24659, 946, 80, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[24742, 950, 79, 2, 27, "Output"]
}, Open  ]],
Cell[24836, 955, 176, 4, 50, "Text",
  CellTags->{"S0.1", "1.12"}],
Cell[25015, 961, 141, 5, 30, "MathCaption",
  CellTags->{"S0.1", "1.13"}],
Cell[25159, 968, 316, 11, 132, "Input",
  CellTags->"S0.1"],
Cell[25478, 981, 138, 5, 30, "MathCaption",
  CellTags->{"S0.1", "1.15"}],

Cell[CellGroupData[{
Cell[25641, 990, 80, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[25724, 994, 89, 2, 27, "Output"]
}, Open  ]],
Cell[25828, 999, 135, 5, 30, "MathCaption",
  CellTags->{"S0.1", "1.16"}],

Cell[CellGroupData[{
Cell[25988, 1008, 83, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[26074, 1012, 80, 2, 27, "Output"]
}, Open  ]],
Cell[26169, 1017, 93, 1, 30, "MathCaption",
  CellTags->{"S0.1", "1.17"}],

Cell[CellGroupData[{
Cell[26287, 1022, 84, 2, 27, "Input",
  CellTags->"S0.1"],
Cell[26374, 1026, 79, 2, 27, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

